<html>
<head>

    <title>django-mongonaut</title>
    <link rel="stylesheet" type="text/css" href="http://twitter.github.com/bootstrap/1.4.0/bootstrap.min.css">
</head>


<body>
<ul class="breadcrumb">
    {% block breadcrumbs %}
    {% endblock %}
</ul>    
<div class="container">
{% block content %}{% endblock %}
    <footer>
        <p>
            &copy; 2012 <a href="http://pydanny.blogspot.com.com">Daniel Greenfeld</a>
            - <a href="http://github.com/pydanny/django-mongonaut">Fork on Github!</a>
            - <a href="http://django-mongonaut.rtfd.org">Documentation</a>
        </p>
    </footer>
</div>



</body>
</html>