{% extends "mongonaut/base.html" %}
{% load mongonaut_tags %}

{% block breadcrumbs %}
<li><a href="{% url index %}">Mongonaut</a> <span class="divider">/</span></li>
<li><a href="{% url document_list app_label document_name %}">{{ document_name }}s</a> <span class="divider">/</span></li>
<li><a href="">Add</a>
{% endblock %}

{% block content %}

<h1>{{ document_name }} Detail Edit</h1>

<div class="row">
    <div class="span16">
        <form method="post" action="">
            {% csrf_token %}
            <fieldset>
                {% for field in form %}
                    {% include "mongonaut/includes/_field.html" %}
                {% endfor %}
            </fieldset>
            <div class="actions">
                <input type="submit" name="action" class="btn primary" value="Save">&nbsp;
                <input type="submit" name="action" class="btn disabled" readonly value="Save and continue editing">&nbsp;                
                <input type="submit" name="action" class="btn disabled" readonly value="Save and add another">&nbsp;                                                
                <input type="submit" name="action" class="btn danger disabled" readonly value="X Delete">&nbsp;
            </div>            
        </form>        
    </div>
</div>    

{% endblock %}
