{% if field.is_hidden %}
    {{ field }}
{% else %}
<div class="clearfix {% if field.errors %}error{% endif %}">
    <label for="{{ field.auto_id }}" {% if field.field.required %}class="requiredField"{% endif %}>
        {{ field.label|safe }}{% if field.field.required %}<span class="asteriskField">*</span>{% endif %}
    </label>
    <div class="input">
        {{ field }}
        {% if field.errors %}
            <span class="help-block">
                {% for error in field.errors %}
                    {{ error }}
                {% endfor %}
            </span>
        {% endif %}        
        
        {% if field.help_text %}
            <span class="help-block">
                {% if field.help_text %}
                    {{ field.help_text|safe }}
                {% endif %}
            </span>
        {% endif %}
            
            
        
    </div>
</div>
{% endif %}